@@ -15,7 +15,6 @@ from dbt.clients.system import run_cmd
 from dbt.compilation import compile_manifest
 from dbt.config import PROFILES_DIR, RuntimeConfig
 from dbt.contracts.graph.manifest import Manifest
-from dbt.exceptions import RuntimeException
 from dbt.graph.selector import NodeSelector
 from dbt.logger import GLOBAL_LOGGER as logger
 from dbt.node_types import NodeType
@@ -30,6 +29,7 @@ from ddbt.constants import (
     GRANULARITY_STEP,
     get_commit_diff,
 )
+from ddbt.exceptions import NoModelsFoundException
 
 
 @attr.s(auto_attribs=True)
@@ -198,7 +198,7 @@ class GitTask(BaseTask):
             filter_suffix (List[str]): filter changes by suffix.
 
         Raises:
-            RuntimeException: no models are found.
+            NoModelsFoundException: no models are found.
 
         Returns:
             Set[str]: Set of modifed and untracked files.
@@ -212,9 +212,27 @@ class GitTask(BaseTask):
             if Path(change).suffix in filter_suffix
         }
         if not result:
-            raise RuntimeException(f"No model changes found. Cmd: {' '.join(cmd)}")
+            raise NoModelsFoundException(
+                red(f"No model changes found. Cmd: {' '.join(cmd)}")
+            )
         return result
 
+    def _update_models(self) -> List[str]:
+        models_tmp = self._prepare_models()
+
+        filtered_manifest = self._get_filtered_manifest(
+            models=models_tmp,
+            exclude=self.exclude,
+            resource_types=[NodeType.Model],
+            materialization=self.materialization,
+        )
+        models = [node.identifier for _, node in filtered_manifest.nodes.items()]
+
+        if not models:
+            raise NoModelsFoundException(red("No model found!"))
+
+        return models
+
     def _prepare_models(self) -> Optional[List[str]]:
         """Get list of models from git.
 
